
BODY {
	padding-top: 60px;
	padding-bottom: 60px;
}

.navbar-fixed-top {
	z-index: 1045;
}

.hidden {
	display: none;
}

.toleft {
	float: left;
	margin-right: 10px;
}

.toright {
	float: right;
	margin-left: 10px;
}

.centered {
	text-align: center;
	clear: both;
}

.nofloat {
	float: none !important;
	margin: 0px !important;
	width: 100% !important;
}

.clearer {
	clear: both;
	height: 0px !important;
	font-size: 0px;
}

.logged-in {
	float: right;
}

FORM {
	margin-bottom: 0px;
}

.sidebar-nav {
	width: 19%;
	margin-right: 10px;
}

.nav-list .icon-chevron-right {
	float: right;
	opacity: 0.4;
	filter: opacity(40);
}

.nav-list P {
	font-size: 12px;
	line-height: 14px;
}

.nav-list A:hover .icon-chevron-right,
.nav-list .active .icon-chevron-right {
	opacity: 0.9;
	filter: opacity(90);
}

.social,
.fblike,
.plusone {
	float: right;
}

.social:after {
	clear: both;
}


.ISiteManager .topics {
	background-color: #444;
	border-radius: 5px;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	padding: 10px;
	color: #eee;
}

.ISiteManager > .container-fluid {
	padding-left: 20px;
	padding-right: 20px;
}

.ISiteManager > .container-fluid .container-fluid {
	padding-left: 0px;
	padding-right: 0px;
}

.topics H2 {
	margin-top: 0px;
	margin-bottom: 0px;
	font-size: 20px;
	line-height: 25px;
}

.ISiteManager .topics A:hover {
	color: #00aaee;
}

.topic H3 {
	line-height: 25px;
	margin: 15px 0px 5px;
}

.topic .publication {
	font-size: 85%;
	margin-bottom: 20px;
}

.topics .topic .publication {
	margin-bottom: 5px;
}

.topics P {
	margin-bottom: 0px;
}

.IBlog .topics .topic,
.ISection .topics .topic {
	margin-bottom: 10px;
}

.ISiteManager .topics .topic {
	margin-top: 15px;
}

.ISiteManager .topics .topic:first-child {
	margin-top: 0px;
}

.ISiteManager .topics .publication {
	color: #aaa;
}

.topic .footer .tags {
	text-align: right;
	margin-bottom: 10px;
}

.tag {
	border: 1px solid #0088cc;
	margin-right: 3px;
	padding: 0px 3px;
	border-radius: 3px;
}

.img_wrapper .thumbnail {
	padding: 0px;
	border-radius: 0px;
}

.credits {
	color: #999999;
	text-align: center;
	padding: 10px 15px;
}

IFRAME.code {
	border: None;
	width: 100%;
}


.pages {
	display: inline-block;
	margin: 5px 0px;
	overflow: hidden;
	background-color: #efefef;
	background-image: -moz-linear-gradient(#fff, #efefef);
	background-image: -webkit-linear-gradient(#fff, #efefef);
	background-image: linear-gradient(#fff, #efefef);
	background-repeat: repeat-x;
	border: 1px solid #eaeaea;
	border-bottom-color: #cacaca;
	border-bottom: none;
	border-radius: 3px;
}

.pages A {
	float: left;
	padding: 5px 6px 4px;
	margin: 0;
	color: #777;
	text-decoration: none;
	text-shadow: 0 1px 0 white;
	border-top: 1px solid transparent;
	border-right: 1px solid rgba(0,0,0,0.04);
	border-left: 1px solid rgba(255,255,255,0.7);
	border-bottom: 1px solid #dadada;
}

.pages A[href]:hover {
	background-color: #efefef;
	background-image: -moz-linear-gradient(#efefef, #fff);
	background-image: -webkit-linear-gradient(#efefef, #fff);
	background-image: linear-gradient(#efefef, #fff);
	border-left: 1px solid rgba(0,0,0,0.04);
	border-right: 1px solid rgba(255,255,255,0.7);
	border-top: 1px solid #dadada;
	border-bottom: 1px solid transparent;
}

.pages A:first-child {
	border-left-color: transparent;
	border-bottom-left-radius: 3px;
}

.pages A:last-child {
	border-right-color: transparent;
	border-bottom-right-radius: 3px;
}

.pages A.current,
.pages A.current:hover {
	color: #666;
	background-color: #ebebeb;
	background-image: -moz-linear-gradient(#fcfcfc, #ebebeb);
	background-image: -webkit-linear-gradient(#fcfcfc, #ebebeb);
	background-image: linear-gradient(#fcfcfc, #ebebeb);
	background-repeat: repeat-x;
	border-top: 1px solid transparent;
	border-right: 1px solid rgba(0,0,0,0.04);
	border-left: 1px solid rgba(255,255,255,0.7);
	border-bottom: 1px solid #444;
}

@media (max-width: 979px) {

	body {
		padding-top: 0;
	}

	BODY.ISiteManager > .container-fluid {
		padding-left: 10px;
		padding-right: 10px;
	}

	.container-fluid {
		padding-left: 10px;
		padding-right: 10px;
	}

	.navbar .brand {
		margin-left: 5px;
	}

}


@media (max-width: 767px) {

	body {
		padding-top: 0;
		padding-left: 5px;
		padding-right: 5px;
	}

	.sidebar-nav {
		position: inherit;
		width: auto;
		margin-right: 0px;
	}

	.container-fluid {
		padding-left: 5px;
		padding-right: 5px;
	}

}
